PixerMetadata class final

Width, height, and color layout of an image.

Constructors

PixerMetadata({required int width, required int height, required ColorType colorType})
const
PixerMetadata.fromNative(Pointer<ImageMetadata> ptr)
Creates metadata from the native struct.
factory

Properties

colorType ColorType
Pixel layout (channels present).
final
hashCode int
The hash code for this object.
no setteroverride
height int
Image height in pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Image width in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override